@@ -9,14 +9,20 @@ with 'Catalyst::TraitFor::Model::DBIC::Schema::PerRequestSchema' => {
 };
 
 BEGIN {
-    our $VERSION = '0.06'; # VERSION
+    our $VERSION = '0.07'; # VERSION
 }
 
 # ABSTRACT: Puts the context's current user into your Catalyst::Model::DBIC::Schema schema.
 
+our $RECURSION = 0;
+
 sub per_request_schema_attributes {
     my ($self, $ctx) = @_;
 
+    local $RECURSION = $RECURSION + 1;
+
+    return () if $RECURSION > 1;
+
     return () unless ( $ctx->user_exists );
 
     return ( current_user => $ctx->user );
